@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2004-2014                                               *
+ *   copyright (C) 2004-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -27,7 +27,7 @@ class UMLClassifier;
  * @author Gopala Krishna
  *
  * @see UMLWidget
- * Bugs and comments to umbrello-devel@kde.org or http://bugs.kde.org
+ * Bugs and comments to umbrello-devel@kde.org or https://bugs.kde.org
  */
 class ClassifierWidget : public UMLWidget
 {
@@ -91,7 +91,6 @@ public:
 
     AssociationWidget *classAssociationWidget() const;
     void setClassAssociationWidget(AssociationWidget *assocwidget);
-//    virtual void adjustAssociations(int x, int y);
  
     UMLWidget* onWidget(const QPointF& p);
     UMLWidget* widgetWithID(Uml::ID::Type id);
@@ -116,6 +115,9 @@ private Q_SLOTS:
     void slotShowAttributes(bool state);
     void slotShowOperations(bool state);
 
+protected:
+    virtual void mouseDoubleClickEvent(QGraphicsSceneMouseEvent *event);
+
 private:
     void updateSignatureTypes();
     QSize calculateTemplatesBoxSize() const;
